Documentation
¶
Overview ¶
Package exiftool provides a pure Go wrapper around ExifTool via WebAssembly. It uses zeroperl (Perl compiled to WebAssembly) and wazero (pure Go wasm runtime) to provide ExifTool functionality without any external dependencies.
Index ¶
- type ExifTool
- func (et *ExifTool) Close() error
- func (et *ExifTool) ReadMetadata(filePath string) (map[string]any, error)
- func (et *ExifTool) SetTag(srcPath string, dstPath string, tag string, value string) error
- func (et *ExifTool) Version() (string, error)
- func (et *ExifTool) WriteMetadata(srcPath string, dstPath string, tags map[string]any) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExifTool ¶
type ExifTool struct {
// contains filtered or unexported fields
}
ExifTool represents an ExifTool instance backed by WebAssembly.
func NewWithContext ¶
NewWithContext creates a new ExifTool instance with the given context.
func (*ExifTool) ReadMetadata ¶
ReadMetadata reads metadata from an image file.
func (*ExifTool) SetTag ¶
SetTag writes a single tag to an image file. If dstPath is empty, the source file is modified in place.
Click to show internal directories.
Click to hide internal directories.